==> xchm-1.17-i486-1gv.txz: install/doinst.sh <==
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
        usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
        usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
( cd usr/share/icons/hicolor/128x128/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/128x128/apps ; ln -sf ../../../../pixmaps/xchm-128.xpm xchm.xpm )
( cd usr/share/icons/hicolor/128x128/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/128x128/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-128.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf ../../../../pixmaps/xchm-48.xpm xchm.xpm )
( cd usr/share/icons/hicolor/48x48/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/48x48/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-48.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/32x32/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/32x32/apps ; ln -sf ../../../../pixmaps/xchm-32.xpm xchm.xpm )
( cd usr/share/icons/hicolor/32x32/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/32x32/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-32.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/16x16/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/16x16/apps ; ln -sf ../../../../pixmaps/xchm-16.xpm xchm.xpm )
( cd usr/share/icons/hicolor/16x16/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/16x16/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-16.xpm gnome-mime-application-x-chm.xpm )

==> xchm-1.23-i486-1gv.txz: install/doinst.sh <==
( cd usr/share/icons/hicolor/128x128/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/128x128/apps ; ln -sf ../../../../pixmaps/xchm-128.xpm xchm.xpm )
( cd usr/share/icons/hicolor/128x128/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/128x128/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-128.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf ../../../../pixmaps/xchm-48.xpm xchm.xpm )
( cd usr/share/icons/hicolor/48x48/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/48x48/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-48.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/32x32/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/32x32/apps ; ln -sf ../../../../pixmaps/xchm-32.xpm xchm.xpm )
( cd usr/share/icons/hicolor/32x32/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/32x32/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-32.xpm gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/16x16/apps ; rm -rf xchm.xpm )
( cd usr/share/icons/hicolor/16x16/apps ; ln -sf ../../../../pixmaps/xchm-16.xpm xchm.xpm )
( cd usr/share/icons/hicolor/16x16/mimetypes ; rm -rf gnome-mime-application-x-chm.xpm )
( cd usr/share/icons/hicolor/16x16/mimetypes ; ln -sf ../../../../pixmaps/xchmdoc-16.xpm gnome-mime-application-x-chm.xpm )

doinst() {
# update the mime desktop database
if [ -x /usr/bin/update-desktop-database ]; then
        /usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x /usr/bin/update-mime-database ]; then
        /usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
}
doinst
